@@ -1,6 +1,4 @@
-
 describe('GridLayer', function () {
-
 	var div, map;
 
 	beforeEach(function () {
@@ -15,6 +13,7 @@ describe('GridLayer', function () {
 	});
 
 	afterEach(function () {
+		map.remove();
 		document.body.removeChild(div);
 	});
 
@@ -44,7 +43,6 @@ describe('GridLayer', function () {
 	});
 
 	it('positions tiles correctly with wrapping and bounding', function () {
-
 		map.setView([0, 0], 1);
 
 		var tiles = [];
@@ -107,7 +105,7 @@ describe('GridLayer', function () {
 				delete tiles[grid._tileCoordsToKey(e.coords)];
 			});
 
-			grid.on('load', function (e) {
+			grid.on('load', function () {
 				if (Object.keys(tiles).length === 1) {
 					expect(Object.keys(tiles)).to.eql(['0:0:0']);
 					grid.off();
@@ -129,27 +127,21 @@ describe('GridLayer', function () {
 			div.style.width = '512px';
 			div.style.height = '512px';
 
-			map.remove();
-			map = L.map(div);
 			map.setView([0, 0], 10);
 
 			grid = L.gridLayer();
 		});
 
-		afterEach(function () {
-			div.style.width = '800px';
-			div.style.height = '600px';
-		});
-
 		// Passes on Firefox, but fails on phantomJS: done is never called.
 		it('only creates tiles for visible area on zoom in', function (done) {
+			map._zoomAnimated = false; // fixme https://github.com/Leaflet/Leaflet/issues/7116
 			var count = 0,
 			    loadCount = 0;
-			grid.createTile = function (coords) {
+			grid.createTile = function () {
 				count++;
 				return document.createElement('div');
 			};
-			var onLoad = function (e) {
+			var onLoad = function () {
 				expect(count).to.eql(4);
 				count = 0;
 				loadCount++;
@@ -237,13 +229,15 @@ describe('GridLayer', function () {
 	});
 
 	describe("#getMaxZoom, #getMinZoom", function () {
+		beforeEach(function () {
+			map.setView([0, 0], 1);
+		});
+
 		describe("when a tilelayer is added to a map with no other layers", function () {
 			it("has the same zoomlevels as the tilelayer", function () {
 				var maxZoom = 10,
 				    minZoom = 5;
 
-				map.setView([0, 0], 1);
-
 				L.gridLayer({
 					maxZoom: maxZoom,
 					minZoom: minZoom
@@ -256,8 +250,6 @@ describe('GridLayer', function () {
 
 		describe("accessing a tilelayer's properties", function () {
 			it('provides a container', function () {
-				map.setView([0, 0], 1);
-
 				var layer = L.gridLayer().addTo(map);
 				expect(layer.getContainer()).to.be.ok();
 			});
@@ -265,8 +257,6 @@ describe('GridLayer', function () {
 
 		describe("when a tilelayer is added to a map that already has a tilelayer", function () {
 			it("has its zoomlevels updated to fit the new layer", function () {
-				map.setView([0, 0], 1);
-
 				L.gridLayer({minZoom: 10, maxZoom: 15}).addTo(map);
 				expect(map.getMinZoom()).to.be(10);
 				expect(map.getMaxZoom()).to.be(15);
@@ -294,31 +284,28 @@ describe('GridLayer', function () {
 					L.gridLayer({minZoom: 10, maxZoom: 20}).addTo(map),
 					L.gridLayer({minZoom: 0, maxZoom: 25}).addTo(map)
 				];
-				map.whenReady(function () {
-					expect(map.getMinZoom()).to.be(0);
-					expect(map.getMaxZoom()).to.be(25);
+				expect(map.getMinZoom()).to.be(0);
+				expect(map.getMaxZoom()).to.be(25);
 
-					map.removeLayer(tiles[0]);
-					expect(map.getMinZoom()).to.be(0);
-					expect(map.getMaxZoom()).to.be(25);
+				map.removeLayer(tiles[0]);
+				expect(map.getMinZoom()).to.be(0);
+				expect(map.getMaxZoom()).to.be(25);
 
-					map.removeLayer(tiles[3]);
-					expect(map.getMinZoom()).to.be(5);
-					expect(map.getMaxZoom()).to.be(20);
+				map.removeLayer(tiles[3]);
+				expect(map.getMinZoom()).to.be(5);
+				expect(map.getMaxZoom()).to.be(20);
 
-					map.removeLayer(tiles[2]);
-					expect(map.getMinZoom()).to.be(5);
-					expect(map.getMaxZoom()).to.be(10);
+				map.removeLayer(tiles[2]);
+				expect(map.getMinZoom()).to.be(5);
+				expect(map.getMaxZoom()).to.be(10);
 
-					map.removeLayer(tiles[1]);
-					expect(map.getMinZoom()).to.be(0);
-					expect(map.getMaxZoom()).to.be(Infinity);
-				});
+				map.removeLayer(tiles[1]);
+				expect(map.getMinZoom()).to.be(0);
+				expect(map.getMaxZoom()).to.be(Infinity);
 			});
 		});
 	});
 
-
 	describe("min/maxNativeZoom option", function () {
 		it("calls createTile() with maxNativeZoom when map zoom is larger", function (done) {
 			map.setView([0, 0], 10);
@@ -414,7 +401,6 @@ describe('GridLayer', function () {
 		});
 
 		it("Loads 8 tiles zoom 1", function (done) {
-
 			grid.on('load', function () {
 				expect(counts.tileloadstart).to.be(8);
 				expect(counts.tileload).to.be(8);
@@ -427,7 +413,6 @@ describe('GridLayer', function () {
 		});
 
 		it("Loads 5 tiles zoom 0", function (done) {
-
 			grid.on('load', function () {
 				expect(counts.tileloadstart).to.be(5);
 				expect(counts.tileload).to.be(5);
@@ -440,7 +425,6 @@ describe('GridLayer', function () {
 		});
 
 		it("Loads 16 tiles zoom 10", function (done) {
-
 			grid.on('load', function () {
 				expect(counts.tileloadstart).to.be(16);
 				expect(counts.tileload).to.be(16);
@@ -455,7 +439,6 @@ describe('GridLayer', function () {
 		});
 
 		it("Loads 32, unloads 16 tiles zooming in 10-11", function (done) {
-
 			grid.on('load', function () {
 				expect(counts.tileloadstart).to.be(16);
 				expect(counts.tileload).to.be(16);
@@ -479,7 +462,6 @@ describe('GridLayer', function () {
 		});
 
 		it("Loads 32, unloads 16 tiles zooming out 11-10", function (done) {
-
 			grid.on('load', function () {
 				expect(counts.tileloadstart).to.be(16);
 				expect(counts.tileload).to.be(16);
@@ -502,9 +484,7 @@ describe('GridLayer', function () {
 			clock.tick(250);
 		});
 
-
 		it("Loads 32, unloads 16 tiles zooming out 18-10", function (done) {
-
 			grid.on('load', function () {
 				expect(counts.tileloadstart).to.be(16);
 				expect(counts.tileload).to.be(16);
@@ -522,16 +502,12 @@ describe('GridLayer', function () {
 				clock.tick(250);
 			});
 
-
 			map.addLayer(grid).setView([0, 0], 18);
 			clock.tick(250);
 		});
-
 	});
 
-
 	describe("number of 256px tiles loaded in synchronous animated grid @800x600px", function () {
-
 		var clock, grid, counts;
 
 		beforeEach(function () {
@@ -569,6 +545,7 @@ describe('GridLayer', function () {
 		});
 
 		// Debug helper
+		/*
 		function logTiles(ev) {
 			var pending = 0;
 			for (var key in grid._tiles) {
@@ -576,7 +553,7 @@ describe('GridLayer', function () {
 			}
 			console.log(ev.type + ': ', ev.coords, grid._loading, counts, ' pending: ', pending);
 		}
-
+		*/
 
 		// animationFrame helper, just runs requestAnimFrame() a given number of times
 		function runFrames(n) {
@@ -597,8 +574,7 @@ describe('GridLayer', function () {
 
 		// NOTE: This test has different behaviour in PhantomJS and graphical
 		// browsers due to CSS animations!
-		it.skipInPhantom("Loads 32, unloads 16 tiles zooming in 10-11", function (done) {
-
+		it.skipIfNo3d("Loads 32, unloads 16 tiles zooming in 10-11", function (done) {
 			// Advance the time to !== 0 otherwise `tile.loaded` timestamp will appear to be falsy.
 			clock.tick(1);
 			// Date.now() is 1.
@@ -708,8 +684,7 @@ describe('GridLayer', function () {
 
 		// NOTE: This test has different behaviour in PhantomJS and graphical
 		// browsers due to CSS animations!
-		it.skipInPhantom("Loads 32, unloads 16 tiles zooming out 11-10", function (done) {
-
+		it.skipIfNo3d("Loads 32, unloads 16 tiles zooming out 11-10", function (done) {
 			// Advance the time to !== 0 otherwise `tile.loaded` timestamp will appear to be falsy.
 			clock.tick(1);
 			// Date.now() is 1.
@@ -783,7 +758,6 @@ describe('GridLayer', function () {
 		});
 
 		it("Loads 32, unloads 16 tiles zooming out 18-10", function (done) {
-
 			grid.on('load', function () {
 				expect(counts.tileloadstart).to.be(16);
 				expect(counts.tileload).to.be(16);
@@ -812,8 +786,7 @@ describe('GridLayer', function () {
 
 		// NOTE: This test has different behaviour in PhantomJS and graphical
 		// browsers due to CSS animations!
-		it.skipInPhantom("Loads 290, unloads 275 tiles on MAD-TRD flyTo()", function (done) {
-
+		it.skipIfNo3d("Loads 290, unloads 275 tiles on MAD-TRD flyTo()", function (done) {
 			this.timeout(10000); // This test takes longer than usual due to frames
 
 			var mad = [40.40, -3.7], trd = [63.41, 10.41];
@@ -896,7 +869,6 @@ describe('GridLayer', function () {
 		// NOTE: This test has different behaviour in PhantomJS and graphical
 		// browsers due to CSS animations!
 		it("Loads map, moves forth by 512 px, keepBuffer = 0", function (done) {
-
 			// Advance the time to !== 0 otherwise `tile.loaded` timestamp will appear to be falsy.
 			clock.tick(1);
 			// Date.now() is 1.
@@ -944,7 +916,6 @@ describe('GridLayer', function () {
 					// OOOO
 					map.panBy([512, 512], {animate: false});
 					// clock.tick(250);
-
 				});
 			});
 
@@ -958,7 +929,6 @@ describe('GridLayer', function () {
 		// NOTE: This test has different behaviour in PhantomJS and graphical
 		// browsers due to CSS animations!
 		it("Loads map, moves forth and back by 512 px, keepBuffer = 0", function (done) {
-
 			grid.once('load', function () {
 				expect(counts.tileloadstart).to.be(16);
 				expect(counts.tileload).to.be(16);
@@ -1003,7 +973,6 @@ describe('GridLayer', function () {
 		});
 
 		it("Loads map, moves forth and back by 512 px, default keepBuffer", function (done) {
-
 			var spy = sinon.spy();
 
 			grid.on('load', function () {
@@ -1038,7 +1007,6 @@ describe('GridLayer', function () {
 
 	describe("nowrap option", function () {
 		it("When false, uses same coords at zoom 0 for all tiles", function (done) {
-
 			var grid = L.gridLayer({
 				attribution: 'Grid Layer',
 				tileSize: L.point(256, 256),
@@ -1060,7 +1028,6 @@ describe('GridLayer', function () {
 		});
 
 		it("When true, uses different coords at zoom level 0 for all tiles", function (done) {
-
 			var grid = L.gridLayer({
 				attribution: 'Grid Layer',
 				tileSize: L.point(256, 256),
@@ -1082,7 +1049,6 @@ describe('GridLayer', function () {
 		});
 
 		it("When true and with bounds, loads just one tile at zoom level 0", function (done) {
-
 			var grid = L.gridLayer({
 				attribution: 'Grid Layer',
 				tileSize: L.point(256, 256),
