@@ -1,24 +1,35 @@
 describe("Map", function () {
-	var map,
-	    spy;
+	var container,
+	    map;
+
 	beforeEach(function () {
-		map = L.map(document.createElement('div'));
+		container = document.createElement('div');
+		document.body.appendChild(container);
+		map = L.map(container);
+	});
+
+	afterEach(function () {
+		if (container._leaflet_id) {
+			map.remove();
+		}
+		document.body.removeChild(container);
 	});
 
 	describe("#remove", function () {
+		var spy;
+
+		beforeEach(function () {
+			spy = sinon.spy();
+		});
+
 		it("fires an unload event if loaded", function () {
-			var container = document.createElement('div'),
-			    map = new L.Map(container).setView([0, 0], 0),
-			    spy = sinon.spy();
+			map.setView([0, 0], 0);
 			map.on('unload', spy);
 			map.remove();
 			expect(spy.called).to.be.ok();
 		});
 
 		it("fires no unload event if not loaded", function () {
-			var container = document.createElement('div'),
-			    map = new L.Map(container),
-			    spy = sinon.spy();
 			map.on('unload', spy);
 			map.remove();
 			expect(spy.called).not.to.be.ok();
@@ -26,14 +37,11 @@ describe("Map", function () {
 
 		describe("corner case checking", function () {
 			it("throws an exception upon reinitialization", function () {
-				var container = document.createElement('div'),
-				    map = new L.Map(container);
 				expect(function () {
 					L.map(container);
 				}).to.throwException(function (e) {
 					expect(e.message).to.eql("Map container is already initialized.");
 				});
-				map.remove();
 			});
 
 			it("throws an exception if a container is not found", function () {
@@ -42,22 +50,24 @@ describe("Map", function () {
 				}).to.throwException(function (e) {
 					expect(e.message).to.eql("Map container not found.");
 				});
-				map.remove();
 			});
 		});
 
-		it("undefines container._leaflet", function () {
-			var container = document.createElement('div'),
-			    map = new L.Map(container);
+		it("undefines container._leaflet_id", function () {
+			expect(container._leaflet_id).to.be.ok();
 			map.remove();
-			expect(container._leaflet).to.be(undefined);
+			expect(container._leaflet_id).to.be(undefined);
 		});
 
 		it("unbinds events", function () {
-			var container = document.createElement('div'),
-			    map = new L.Map(container).setView([0, 0], 1),
-			    spy = sinon.spy();
+			// before actual test: make sure that events are ok
+			map.setView([0, 0], 0);
+			map.on('click', spy);
+			happen.click(container);
+			expect(spy.called).to.be.ok();
 
+			// actual test
+			spy = sinon.spy();
 			map.on('click dblclick mousedown mouseup mousemove', spy);
 			map.remove();
 
@@ -71,29 +81,26 @@ describe("Map", function () {
 		});
 
 		it("does not throw if removed during animation", function () {
-			var container = document.createElement('div'),
-			    map = new L.Map(container).setView([0, 0], 1);
+			map.setView([0, 0], 1).setMaxBounds([[0, 1], [2, 3]]);
 
 			// Force creation of animation proxy,
 			// otherwise browser checks disable it
 			map._createAnimProxy();
 
 			// #6775 Remove the map in the middle of the animation
-			map.on("zoom", map.remove);
+			map.on("zoom", map.remove.bind(map));
 			map.setZoom(2);
 		});
 
 		it("throws error if container is reused by other instance", function () {
-			var container = document.createElement('div'),
-			    map = L.map(container),
-			    map2;
-
 			map.remove();
-			map2 = L.map(container);
+			var map2 = L.map(container);
 
 			expect(function () {
 				map.remove();
 			}).to.throwException();
+
+			map2.remove(); // clean up
 		});
 	});
 
@@ -164,15 +171,17 @@ describe("Map", function () {
 		});
 
 		it("defaults to zoom passed as map option", function () {
-			map = L.map(document.createElement('div'), {zoom: 13});
-			expect(map.setView([51.605, -0.11])).to.be(map);
-			expect(map.getZoom()).to.be(13);
+			var map = L.map(document.createElement('div'), {zoom: 13});
+			var zoom = map.setView([51.605, -0.11]).getZoom();
+			map.remove(); // clean up
+			expect(zoom).to.be(13);
 		});
 
 		it("passes duration option to panBy", function () {
-			map = L.map(document.createElement('div'), {zoom: 13, center: [0, 0]});
+			var map = L.map(document.createElement('div'), {zoom: 13, center: [0, 0]});
 			map.panBy = sinon.spy();
 			map.setView([51.605, -0.11], 13, {animate: true, duration: 13});
+			map.remove(); // clean up
 			expect(map.panBy.callCount).to.eql(1);
 			expect(map.panBy.args[0][1].duration).to.eql(13);
 		});
@@ -180,11 +189,12 @@ describe("Map", function () {
 
 	describe("#getBounds", function () {
 		it("is safe to call from within a moveend callback during initial load (#1027)", function () {
+			var map = L.map(document.createElement('div'));
 			map.on("moveend", function () {
 				map.getBounds();
 			});
-
 			map.setView([51.505, -0.09], 13);
+			map.remove(); // clean up
 		});
 	});
 
@@ -196,17 +206,12 @@ describe("Map", function () {
 		var height = '400px';
 
 		it("returns high levels of zoom with small areas and big padding", function () {
-			var container = map.getContainer();
 			container.style.height = height;
-			document.body.appendChild(container);
 			expect(map.getBoundsZoom(bounds, false, padding)).to.be.equal(19);
 		});
 
-		it.skipInPhantom("returns multiples of zoomSnap when zoomSnap > 0 on any3d browsers", function () {
-			var container = map.getContainer();
+		it.skipIfNo3d("returns multiples of zoomSnap when zoomSnap > 0 on any3d browsers", function () {
 			container.style.height = height;
-			document.body.appendChild(container);
-			// L.Browser.any3d = true;	// L.Browser is frozen since ES6ication
 			map.options.zoomSnap = 0.5;
 			expect(map.getBoundsZoom(bounds, false, padding)).to.be.equal(19.5);
 			map.options.zoomSnap = 0.2;
@@ -216,46 +221,44 @@ describe("Map", function () {
 		});
 
 		it("getBoundsZoom does not return Infinity when projected SE - NW has negative components", function () {
-			var container = map.getContainer();
 			container.style.height = 369;
 			container.style.width = 1048;
-			document.body.appendChild(container);
-			var bounds = L.latLngBounds(L.latLng([62.18475569507688, 6.926335173954951]), L.latLng([62.140483526511694, 6.923933370740089]));
 
-			// The following coordinates are bounds projected with proj4leaflet crs = EPSG:25833', '+proj=utm +zone=33 +ellps=GRS80 +units=m +no_defs
-			var projectedSE = L.point(7800503.059925064, 6440062.353052008);
-			var projectedNW = L.point(7801987.203481699, 6425186.447901004);
-			var crsMock = sinon.mock(map.options.crs);
-			crsMock.expects("project").withArgs(bounds.getNorthWest()).returns(projectedNW);
-			crsMock.expects("project").withArgs(bounds.getSouthEast()).returns(projectedSE);
-
-			var padding = L.point(-50, -50);
 			map.setZoom(16);
-			expect(map.getBoundsZoom(bounds, false, padding)).to.eql(9);
+			var bounds = L.latLngBounds(
+				[62.18475569507688, 6.926335173954951],
+				[62.140483526511694, 6.923933370740089]);
+			var padding = L.point(-50, -50);
+
+			// control case: default crs
+			var boundsZoom = map.getBoundsZoom(bounds, false, padding);
+			expect(boundsZoom).to.eql(9);
+
+			// test case: EPSG:25833 (mocked, for somplicity)
+			// The following coordinates are bounds projected with proj4leaflet crs = EPSG:25833', '+proj=utm +zone=33 +ellps=GRS80 +units=m +no_defs
+			var crsMock = sinon.mock(map.options.crs);
+			crsMock.expects("latLngToPoint")
+				.withExactArgs(bounds.getNorthWest(), 16)
+				.returns(L.point(7800503.059925064, 6440062.353052008));
+			crsMock.expects("latLngToPoint")
+				.withExactArgs(bounds.getSouthEast(), 16)
+				.returns(L.point(7801987.203481699, 6425186.447901004));
+			boundsZoom = map.getBoundsZoom(bounds, false, padding);
+			crsMock.restore();
+
+			crsMock.verify(); // ensure that latLngToPoint was called with expected args
+			expect(boundsZoom).to.eql(7); // result expected for EPSG:25833
 		});
 
 		it("respects the 'inside' parameter", function () {
-			var container = map.getContainer();
 			container.style.height = height;
 			container.style.width = '1024px'; // Make sure the width is defined for browsers other than PhantomJS (in particular Firefox).
-			document.body.appendChild(container);
 			expect(map.getBoundsZoom(wideBounds, false, padding)).to.be.equal(17);
 			expect(map.getBoundsZoom(wideBounds, true, padding)).to.be.equal(20);
 		});
 	});
 
 	describe('#setMaxBounds', function () {
-		var container;
-
-		beforeEach(function () {
-			container = map.getContainer();
-			document.body.appendChild(container);
-		});
-
-		afterEach(function () {
-			// document.body.removeChild(container);
-		});
-
 		it("aligns pixel-wise map view center with maxBounds center if it cannot move view bounds inside maxBounds (#1908)", function () {
 			// large view, cannot fit within maxBounds
 			container.style.width = container.style.height = "1000px";
@@ -301,20 +304,24 @@ describe("Map", function () {
 			});
 			map.setView(center, 18, {animate: false});
 		});
-
 	});
 
 	describe("#getMinZoom and #getMaxZoom", function () {
+		var map;
+
+		afterEach(function () {
+			map.remove(); // clean up
+		});
+
 		describe('#getMinZoom', function () {
 			it('returns 0 if not set by Map options or TileLayer options', function () {
-				var map = L.map(document.createElement('div'));
+				map = L.map(document.createElement('div'));
 				expect(map.getMinZoom()).to.be(0);
 			});
 		});
 
 		it("minZoom and maxZoom options overrides any minZoom and maxZoom set on layers", function () {
-
-			var map = L.map(document.createElement('div'), {minZoom: 2, maxZoom: 20});
+			map = L.map(document.createElement('div'), {minZoom: 2, maxZoom: 20});
 
 			L.tileLayer("{z}{x}{y}", {minZoom: 4, maxZoom: 10}).addTo(map);
 			L.tileLayer("{z}{x}{y}", {minZoom: 6, maxZoom: 17}).addTo(map);
@@ -325,28 +332,28 @@ describe("Map", function () {
 		});
 
 		it("layer minZoom overrides map zoom if map has no minZoom set and layer minZoom is bigger than map zoom", function () {
-			var map = L.map(document.createElement("div"), {zoom: 10});
+			map = L.map(document.createElement("div"), {zoom: 10});
 			L.tileLayer("{z}{x}{y}", {minZoom: 15}).addTo(map);
 
 			expect(map.getMinZoom()).to.be(15);
 		});
 
 		it("layer maxZoom overrides map zoom if map has no maxZoom set and layer maxZoom is smaller than map zoom", function () {
-			var map = L.map(document.createElement("div"), {zoom: 20});
+			map = L.map(document.createElement("div"), {zoom: 20});
 			L.tileLayer("{z}{x}{y}", {maxZoom: 15}).addTo(map);
 
 			expect(map.getMaxZoom()).to.be(15);
 		});
 
 		it("map's zoom is adjusted to layer's minZoom even if initialized with smaller value", function () {
-			var map = L.map(document.createElement("div"), {zoom: 10});
+			map = L.map(document.createElement("div"), {zoom: 10});
 			L.tileLayer("{z}{x}{y}", {minZoom: 15}).addTo(map);
 
 			expect(map.getZoom()).to.be(15);
 		});
 
 		it("map's zoom is adjusted to layer's maxZoom even if initialized with larger value", function () {
-			var map = L.map(document.createElement("div"), {zoom: 20});
+			map = L.map(document.createElement("div"), {zoom: 20});
 			L.tileLayer("{z}{x}{y}", {maxZoom: 15}).addTo(map);
 
 			expect(map.getZoom()).to.be(15);
@@ -356,6 +363,7 @@ describe("Map", function () {
 	describe("#hasLayer", function () {
 		it("returns false when passed undefined, null, or false", function () {
 			var map = L.map(document.createElement('div'));
+			map.remove(); // clean up
 			expect(map.hasLayer(undefined)).to.equal(false);
 			expect(map.hasLayer(null)).to.equal(false);
 			expect(map.hasLayer(false)).to.equal(false);
@@ -370,7 +378,6 @@ describe("Map", function () {
 	}
 
 	describe("#addLayer", function () {
-
 		it("calls layer.onAdd immediately if the map is ready", function () {
 			var layer = layerSpy();
 			map.setView([0, 0], 0);
@@ -423,11 +430,10 @@ describe("Map", function () {
 			expect(spy.called).not.to.be.ok();
 		});
 
-		it("adds the layer before firing layeradd", function (done) {
+		it("adds the layer before firing layeradd", function () {
 			var layer = layerSpy();
 			map.on('layeradd', function () {
 				expect(map.hasLayer(layer)).to.be.ok();
-				done();
 			});
 			map.setView([0, 0], 0);
 			map.addLayer(layer);
@@ -526,11 +532,10 @@ describe("Map", function () {
 			expect(spy.called).not.to.be.ok();
 		});
 
-		it("removes the layer before firing layerremove", function (done) {
+		it("removes the layer before firing layerremove", function () {
 			var layer = layerSpy();
 			map.on('layerremove', function () {
 				expect(map.hasLayer(layer)).not.to.be.ok();
-				done();
 			});
 			map.setView([0, 0], 0);
 			map.addLayer(layer);
@@ -552,54 +557,53 @@ describe("Map", function () {
 
 		describe("when the last tile layer on a map is removed", function () {
 			it("fires a zoomlevelschange event", function () {
-				map.whenReady(function () {
-					var spy = sinon.spy();
-					var tl = L.tileLayer("{z}{x}{y}", {minZoom: 0, maxZoom: 10}).addTo(map);
+				map.setView([0, 0], 0);
+				var spy = sinon.spy();
+				var tl = L.tileLayer("{z}{x}{y}", {minZoom: 0, maxZoom: 10}).addTo(map);
 
-					map.on("zoomlevelschange", spy);
-					expect(spy.called).not.to.be.ok();
-					map.removeLayer(tl);
-					expect(spy.called).to.be.ok();
-				});
+				map.on("zoomlevelschange", spy);
+				expect(spy.called).not.to.be.ok();
+				map.removeLayer(tl);
+				expect(spy.called).to.be.ok();
 			});
 		});
 
 		describe("when a tile layer is removed from a map and it had greater zoom level coverage than the remainding layer", function () {
 			it("fires a zoomlevelschange event", function () {
-				map.whenReady(function () {
-					var spy = sinon.spy(),
-					    tl = L.tileLayer("{z}{x}{y}", {minZoom: 0, maxZoom: 10}).addTo(map),
-					    t2 = L.tileLayer("{z}{x}{y}", {minZoom: 0, maxZoom: 15}).addTo(map);
+				map.setView([0, 0], 0);
+				L.tileLayer("{z}{x}{y}", {minZoom: 0, maxZoom: 10}).addTo(map);
+				var spy = sinon.spy(),
+				    t2 = L.tileLayer("{z}{x}{y}", {minZoom: 0, maxZoom: 15}).addTo(map);
 
-					map.on("zoomlevelschange", spy);
-					expect(spy.called).to.not.be.ok();
-					map.removeLayer(t2);
-					expect(spy.called).to.be.ok();
-				});
+				map.on("zoomlevelschange", spy);
+				expect(spy.called).to.not.be.ok();
+				map.removeLayer(t2);
+				expect(spy.called).to.be.ok();
 			});
 		});
 
-		describe("when a tile layer is removed from a map it and it had lesser or the sa,e zoom level coverage as the remainding layer(s)", function () {
+		describe("when a tile layer is removed from a map it and it had lesser or the same zoom level coverage as the remainding layer(s)", function () {
 			it("fires no zoomlevelschange event", function () {
-				map.whenReady(function () {
-					var tl = L.tileLayer("{z}{x}{y}", {minZoom: 0, maxZoom: 10}).addTo(map),
-					    t2 = L.tileLayer("{z}{x}{y}", {minZoom: 0, maxZoom: 10}).addTo(map),
-					    t3 = L.tileLayer("{z}{x}{y}", {minZoom: 0, maxZoom: 5}).addTo(map);
+				map.setView([0, 0], 0);
+				var spy = sinon.spy(),
+				    t1 = L.tileLayer("{z}{x}{y}", {minZoom: 0, maxZoom: 10}).addTo(map),
+				    t2 = L.tileLayer("{z}{x}{y}", {minZoom: 0, maxZoom: 10}).addTo(map),
+				    t3 = L.tileLayer("{z}{x}{y}", {minZoom: 0, maxZoom: 5}).addTo(map);
 
-					map.on("zoomlevelschange", spy);
-					expect(spy).not.toHaveBeenCalled();
-					map.removeLayer(t2);
-					expect(spy).not.toHaveBeenCalled();
-					map.removeLayer(t3);
-					expect(spy).not.toHaveBeenCalled();
-				});
+				map.on("zoomlevelschange", spy);
+				map.removeLayer(t2);
+				expect(spy.called).to.not.be.ok();
+				map.removeLayer(t3);
+				expect(spy.called).to.not.be.ok();
+				map.removeLayer(t1);
+				expect(spy.called).to.be.ok();
 			});
 		});
 	});
 
 	describe("#eachLayer", function () {
 		it("returns self", function () {
-			expect(map.eachLayer(function () {})).to.be(map);
+			expect(map.eachLayer(L.Util.falseFn)).to.be(map);
 		});
 
 		it("calls the provided function for each layer", function () {
@@ -615,8 +619,8 @@ describe("Map", function () {
 		});
 
 		it("calls the provided function with the provided context", function () {
-			var t1 = L.tileLayer("{z}{x}{y}").addTo(map),
-			    spy = sinon.spy();
+			var spy = sinon.spy();
+			L.tileLayer("{z}{x}{y}").addTo(map);
 
 			map.eachLayer(spy, map);
 
@@ -625,21 +629,17 @@ describe("Map", function () {
 	});
 
 	describe("#invalidateSize", function () {
-		var container,
-		    origWidth = 100,
+		var origWidth = 100,
 		    clock;
 
 		beforeEach(function () {
-			container = map.getContainer();
 			container.style.width = origWidth + "px";
-			document.body.appendChild(container);
 			map.setView([0, 0], 0);
 			map.invalidateSize({pan: false});
 			clock = sinon.useFakeTimers();
 		});
 
 		afterEach(function () {
-			document.body.removeChild(container);
 			clock.restore();
 		});
 
@@ -755,34 +755,20 @@ describe("Map", function () {
 	});
 
 	describe('#flyTo', function () {
-		var div;
-
 		beforeEach(function () {
-			div = document.createElement('div');
-			div.style.width = '800px';
-			div.style.height = '600px';
-			div.style.visibility = 'hidden';
-
-			document.body.appendChild(div);
-
-			map = L.map(div);
-		});
-
-		afterEach(function () {
-			document.body.removeChild(div);
+			container.style.width = '800px';
+			container.style.height = '600px';
+			container.style.visibility = 'hidden';
 		});
 
 		it('move to requested center and zoom, and call zoomend once', function (done) {
 			this.timeout(10000); // This test takes longer than usual due to frames
 
-			var spy = sinon.spy(),
-			    newCenter = new L.LatLng(10, 11),
+			var newCenter = new L.LatLng(10, 11),
 			    newZoom = 12;
 			var callback = function () {
 				expect(map.getCenter()).to.eql(newCenter);
 				expect(map.getZoom()).to.eql(newZoom);
-				spy();
-				expect(spy.calledOnce).to.be.ok();
 				done();
 			};
 			map.setView([0, 0], 0);
@@ -829,8 +815,7 @@ describe("Map", function () {
 			map.zoomOut(null, {animate: false});
 		});
 
-		it.skipInNonPhantom('zoomIn ignores the zoomDelta option on non-any3d browsers', function (done) {
-			L.Browser.any3d = false;
+		it.skipIf3d('zoomIn ignores the zoomDelta option on non-any3d browsers', function (done) {
 			map.options.zoomSnap = 0.25;
 			map.options.zoomDelta = 0.25;
 			map.once('zoomend', function () {
@@ -841,8 +826,7 @@ describe("Map", function () {
 			map.zoomIn(null, {animate: false});
 		});
 
-		it.skipInPhantom('zoomIn respects the zoomDelta option on any3d browsers', function (done) {
-			L.Browser.any3d = true;
+		it.skipIfNo3d('zoomIn respects the zoomDelta option on any3d browsers', function (done) {
 			map.options.zoomSnap = 0.25;
 			map.options.zoomDelta = 0.25;
 			map.setView(center, 10);
@@ -854,8 +838,7 @@ describe("Map", function () {
 			map.zoomIn(null, {animate: false});
 		});
 
-		it.skipInPhantom('zoomOut respects the zoomDelta option on any3d browsers', function (done) {
-			L.Browser.any3d = true;
+		it.skipIfNo3d('zoomOut respects the zoomDelta option on any3d browsers', function (done) {
 			map.options.zoomSnap = 0.25;
 			map.options.zoomDelta = 0.25;
 			map.setView(center, 10);
@@ -867,7 +850,7 @@ describe("Map", function () {
 			map.zoomOut(null, {animate: false});
 		});
 
-		it.skipInPhantom('zoomIn snaps to zoomSnap on any3d browsers', function (done) {
+		it.skipIfNo3d('zoomIn snaps to zoomSnap on any3d browsers', function (done) {
 			map.options.zoomSnap = 0.25;
 			map.setView(center, 10);
 			map.once('zoomend', function () {
@@ -875,11 +858,10 @@ describe("Map", function () {
 				expect(map.getCenter()).to.eql(center);
 				done();
 			});
-			L.Browser.any3d = true;
 			map.zoomIn(0.22, {animate: false});
 		});
 
-		it.skipInPhantom('zoomOut snaps to zoomSnap on any3d browsers', function (done) {
+		it.skipIfNo3d('zoomOut snaps to zoomSnap on any3d browsers', function (done) {
 			map.options.zoomSnap = 0.25;
 			map.setView(center, 10);
 			map.once('zoomend', function () {
@@ -887,7 +869,6 @@ describe("Map", function () {
 				expect(map.getCenter()).to.eql(center);
 				done();
 			});
-			L.Browser.any3d = true;
 			map.zoomOut(0.22, {animate: false});
 		});
 	});
@@ -910,16 +891,10 @@ describe("Map", function () {
 
 		beforeEach(function () {
 			// fitBounds needs a map container with non-null area
-			var container = map.getContainer();
 			container.style.width = container.style.height = "100px";
-			document.body.appendChild(container);
 			map.setView(center, 15);
 		});
 
-		afterEach(function () {
-			document.body.removeChild(map.getContainer());
-		});
-
 		it('Snaps zoom level to integer by default', function (done) {
 			map.once('zoomend', function () {
 				expect(map.getZoom()).to.eql(2);
@@ -929,9 +904,8 @@ describe("Map", function () {
 			map.fitBounds(bounds, {animate: false});
 		});
 
-		it.skipInPhantom('Snaps zoom to zoomSnap on any3d browsers', function (done) {
+		it.skipIfNo3d('Snaps zoom to zoomSnap on any3d browsers', function (done) {
 			map.options.zoomSnap = 0.25;
-			L.Browser.any3d = true;
 			map.once('zoomend', function () {
 				expect(map.getZoom()).to.eql(2.75);
 				expect(map.getCenter().equals(boundsCenter, 0.05)).to.eql(true);
@@ -940,9 +914,8 @@ describe("Map", function () {
 			map.fitBounds(bounds, {animate: false});
 		});
 
-		it.skipInNonPhantom('Ignores zoomSnap on non-any3d browsers', function (done) {
+		it.skipIf3d('Ignores zoomSnap on non-any3d browsers', function (done) {
 			map.options.zoomSnap = 0.25;
-			L.Browser.any3d = false;
 			map.once('zoomend', function () {
 				expect(map.getZoom()).to.eql(2);
 				expect(map.getCenter().equals(boundsCenter, 0.05)).to.eql(true);
@@ -1011,63 +984,46 @@ describe("Map", function () {
 		});
 	});
 
-
 	describe('#fitBounds after layers set', function () {
 		var center = L.latLng(22, 33),
-		    bounds = L.latLngBounds(L.latLng(1, 102), L.latLng(11, 122)),
-		    boundsCenter = bounds.getCenter();
+		    bounds = L.latLngBounds(L.latLng(1, 102), L.latLng(11, 122));
 
 		beforeEach(function () {
 			// fitBounds needs a map container with non-null area
-			var container = map.getContainer();
 			container.style.width = container.style.height = "100px";
-			document.body.appendChild(container);
 		});
 
-		afterEach(function () {
-			document.body.removeChild(map.getContainer());
-		});
-
-		it('Snaps to a number after adding tile layer', function (done) {
-			L.Browser.any3d = true;
+		it('Snaps to a number after adding tile layer', function () {
+			// expect(L.Browser.any3d).to.be.ok(); // precondition
 			map.addLayer(L.tileLayer('file:///dev/null'));
 			expect(map.getZoom()).to.be(undefined);
 			map.fitBounds(bounds);
 			expect(map.getZoom()).to.be(2);
-			done();
 		});
 
-		it('Snaps to a number after adding marker', function (done) {
-			L.Browser.any3d = true;
+		it('Snaps to a number after adding marker', function () {
+			// expect(L.Browser.any3d).to.be.ok(); // precondition
 			map.addLayer(L.marker(center));
 			expect(map.getZoom()).to.be(undefined);
 			map.fitBounds(bounds);
 			expect(map.getZoom()).to.be(2);
-			done();
 		});
 
 	});
 
-
 	describe("#panInside", function () {
 		var center,
 		    tl,
 		    tlPix;
 
 		beforeEach(function () {
-			var container = map.getContainer();
 			container.style.height = container.style.width = "500px";
-			document.body.appendChild(container);
 			map.setView(L.latLng([53.0, 0.15]), 12, {animate: false});
 			center = map.getCenter();
 			tl = map.getBounds().getNorthWest();
 			tlPix = map.getPixelBounds().min;
 		});
 
-		afterEach(function () {
-			document.body.removeChild(map.getContainer());
-		});
-
 		it("does not pan the map when the target is within bounds", function () {
 			map.panInside(tl, {animate:false});
 			expect(center).to.equal(map.getCenter());
@@ -1102,7 +1058,6 @@ describe("Map", function () {
 
 		it("supports different padding values for each border", function () {
 			var p = tlPix.add([40, 0]),	// Top-Left
-			    distanceMoved,
 			    opts = {paddingTL: [60, 20], paddingBR: [10, 10]};
 			map.panInside(map.unproject(p), opts);
 			expect(center).to.equal(map.getCenter());
@@ -1139,22 +1094,11 @@ describe("Map", function () {
 		});
 	});
 
-
 	describe('#DOM events', function () {
-
-		var c, map;
-
 		beforeEach(function () {
-			c = document.createElement('div');
-			c.style.width = '400px';
-			c.style.height = '400px';
-			map = new L.Map(c);
-			map.setView(new L.LatLng(0, 0), 0);
-			document.body.appendChild(c);
-		});
-
-		afterEach(function () {
-			document.body.removeChild(c);
+			container.style.width = '400px';
+			container.style.height = '400px';
+			map.setView([0, 0], 0);
 		});
 
 		it("DOM events propagate from polygon to map", function () {
@@ -1204,7 +1148,7 @@ describe("Map", function () {
 			map.on("mouseout", mapSpy);
 			layer.on("mouseout", layerSpy);
 			other.on("mouseout", otherSpy);
-			happen.mouseout(layer._path, {relatedTarget: map._container});
+			happen.mouseout(layer._path, {relatedTarget: container});
 			expect(mapSpy.called).not.to.be.ok();
 			expect(otherSpy.called).not.to.be.ok();
 			expect(layerSpy.calledOnce).to.be.ok();
@@ -1220,7 +1164,7 @@ describe("Map", function () {
 			    layer = L.marker([1, 2], {icon: icon}).addTo(map);
 			map.on("mouseout", mapSpy);
 			layer.on("mouseout", layerSpy);
-			happen.mouseout(layer._icon, {relatedTarget: map._container});
+			happen.mouseout(layer._icon, {relatedTarget: container});
 			expect(mapSpy.called).not.to.be.ok();
 			expect(layerSpy.calledOnce).to.be.ok();
 		});
@@ -1266,7 +1210,7 @@ describe("Map", function () {
 			map.on("mouseout", mapSpy);
 			layer.on("mouseout", layerSpy);
 			other.on("mouseout", otherSpy);
-			happen.mouseout(map._container);
+			happen.mouseout(container);
 			expect(otherSpy.called).not.to.be.ok();
 			expect(layerSpy.called).not.to.be.ok();
 			expect(mapSpy.calledOnce).to.be.ok();
@@ -1293,7 +1237,6 @@ describe("Map", function () {
 			});
 			happen.click(layer._icon);
 		});
-
 	});
 
 	describe('#getScaleZoom && #getZoomScale', function () {
